.. _github-stats-3_10_6:

GitHub statistics for 3.10.6 (Aug 29, 2025)
===========================================

GitHub statistics for 2024/12/14 (tag: v3.10.0) - 2025/08/29

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 4 issues and merged 19 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/103?closed=1>`__

The following 31 authors contributed 380 commits.

* Alan Burlot
* Antony Lee
* Christine P. Chai
* David Stansby
* dependabot[bot]
* Doron Behar
* Elliott Sales de Andrade
* G.D. McBain
* Greg Lucas
* hannah
* hu-xiaonan
* Ian Thomas
* Inês Cachola
* Jody Klymak
* Jouni K. Seppänen
* Khushi_29
* Kyle Sunden
* Lumberbot (aka Jack)
* N R Navaneet
* Nathan G. Wiseman
* Oscar Gustafsson
* Praful Gulani
* Qian Zhang
* Raphael Erik Hviding
* Roman
* Ruth Comer
* saikarna913
* Scott Shambaugh
* Thomas A Caswell
* Tim Hoffmann
* Trygve Magnus Ræder

GitHub issues and pull requests:

Pull Requests (19):

* :ghpull:`30487`: Backport PR #30484 on branch v3.10.x (FIX: be more cautious about checking widget size)
* :ghpull:`30484`: FIX: be more cautious about checking widget size
* :ghpull:`30481`: Backport PR #30394 on branch v3.10.x (ENH: Gracefully handle python-build-standalone ImportError with Tk)
* :ghpull:`30477`: Backport PR #30476 on branch v3.10.x (ci: Remove cibuildwheel override for win_arm64/Py3.14)
* :ghpull:`30394`: ENH: Gracefully handle python-build-standalone ImportError with Tk
* :ghpull:`30476`: ci: Remove cibuildwheel override for win_arm64/Py3.14
* :ghpull:`30461`: Backport PR #30451 on branch v3.10.x (doc: factor out quick install tab for reuse)
* :ghpull:`30448`: Backport PR #30412 on branch v3.10.x ({Check,Radio}Buttons: Improve docs of label_props)
* :ghpull:`30412`: {Check,Radio}Buttons: Improve docs of label_props
* :ghpull:`30445`: Backport PR #30444 on branch v3.10.x (Small correction of a typo in the galleries: axis instead of axes)
* :ghpull:`30444`: Small correction of a typo in the galleries: axis instead of axes
* :ghpull:`30430`: Backport PR #30426 on branch v3.10.x (Fix a race condition in TexManager.make_dvi.)
* :ghpull:`30434`: Backport PR #30426: Fix a race condition in TexManager.make_dvi & make_png.
* :ghpull:`30431`: Use pathlib in texmanager.
* :ghpull:`30428`: Backport PR #30399 on branch v3.10.x (Qt: Fix HiDPI handling on X11/Windows)
* :ghpull:`30426`: Fix a race condition in TexManager.make_dvi.
* :ghpull:`30399`: Qt: Fix HiDPI handling on X11/Windows
* :ghpull:`30415`: Backport PR #30414 on branch v3.10.x (DOC: update Cartopy url)
* :ghpull:`30414`: DOC: update Cartopy url

Issues (4):

* :ghissue:`29618`: [Bug]: FigureCanvasQT is seemingly prematurely freed under certain conditions
* :ghissue:`30390`: [ENH]: Gracefully handle python-build-standalone ImportError
* :ghissue:`30420`: [ENH]: Support parallel plotting
* :ghissue:`30386`: BUG: Qt hi-dpi regression on windows and X11 with mpl 3.10.5
